Scripts
=======

This directory contains command-line scripts for an astropy affiliated package.  

POPPY does not have any such scripts; this directory exists solely for consistency
with the standard astropy affiliated package template.

